tietools.remove_all_leaves_in_tie_chain_except_first
====================================================

.. autofunction:: abjad.tools.tietools.remove_all_leaves_in_tie_chain_except_first.remove_all_leaves_in_tie_chain_except_first
